/*! @file    main.c
 *  @brief   ADC进比较中断
 *  @version 2021-06-30  V1.0.0
 *
 * Copyright (C) 2020-2030 NCC Limited. All rights reserved.
 *
 * THIS SOFTWARE IS PROVIDED BY NCC "AS IS" AND ANY EXPRESSED OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL NCC OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "nccm0670_adc.h"
#include "nccm0670_eval.h"
#include "nccm0670_gpio.h"
#include "nccm0670_rcc.h"
#include "systick.h"

#define PIN_ADC_X GPIO_PIN_0
#define PORTx_ADC GPIOC
#define RCC_GPIOx RCC_GPIOC

static volatile uint32_t adc_flag = 0;

int main(void)
{

    gpio_config_t gpio_cfg = {0};
    adc_config_t adc_cfg = {0};
    adc_channel_config_t adc_channel_cfg = {0};
    uint16_t adc_val = 0; 

    systick_init();

    ncc_eval_com_init();
    /* 使能GPIOC时钟 */
    RCC_EnablePeripheralClock(RCC_GPIOx);
    /* 使能ADC时钟 */
    RCC_EnablePeripheralClock(RCC_ADC);
    /* 配置PC0引脚复用为ADC输入端 */
    gpio_cfg.pin = PIN_ADC_X;
    gpio_cfg.mode = GPIO_MODE_ANALOG;
    gpio_cfg.pull = GPIO_NOPULL;
    GPIO_Init(PORTx_ADC, &gpio_cfg);

    ADC_DeInit();
    /*连续转换*/
    adc_cfg.continuous_conv = ADC_CONV_CONTINUOUS;
    /*上升沿触发*/
    adc_cfg.edge = ADC_TRIG_EDGE_RISING;
    /*软件触发*/
    adc_cfg.trigger = ADC_TRIG_SOFT;
    /*分频MCLK = adc_clk/2*/
    adc_cfg.prescaler = ADC_CLOCK_DIV2;
    /*使用内部参考电压*/
    adc_cfg.vref = ADC_VREF_INTERNAL_VBUF_2V5;
    ADC_Init(&adc_cfg);

    /*采样11MCLK*/
    adc_channel_cfg.sampling_time = ADC_SAMPLETIME_11CYCLES;
    /* 触发延时8MCLK */
    adc_channel_cfg.trigger_delay_time = ADC_TRGDL_8CYCLES;
    ADC_StartChannel(ADC_CHANNEL_0, &adc_channel_cfg);

    /*关闭ADC转换完成中断*/
    ADC_SetIntMode(ADC_INT_FINISH, false);
    /*使能比较中断*/
    ADC_SetIntMode(ADC_INT_COMPARE, true);
    /*比较配置*/
    adc_compare_config_t cfg2 = {
        .mode = ADC_COMPARE_MODE_BOTH_LIMIT,
        .high_limit = 0x800,
        .low_limit = 0x400,
    };
    ADC_SetCompare(&cfg2);    

    /* ADC转换开始 */
    ADC_TrigSwConversion();

    /* 设置中断优先级*/
    NVIC_SetPriority(ADC_IRQn, 5);
    /* 使能ADC中断 */
    NVIC_EnableIRQ(ADC_IRQn);

    while (1)
    {
        if(adc_flag == 1)
        {
            /* 获取AD值 */
            adc_val = ADC_GetValue();
            /* 打印AD值 */
            printf("%d\r\n", adc_val);
            adc_flag = 0;
        }
        delay_ms(500);
    }
}

void ADC_IRQHandler(void)
{

    if (ADC_GetIntFlag(ADC_FLAG_COMPARE))
    {
        adc_flag = 1;
        /* 清除标志 */
        ADC_ClearStatusFlag(ADC_FLAG_COMPARE);
    }
}
