/*! @file    main.c
 *  @brief   BTIM定时中断
 *  @version 2021-07-06  V1.0.0
 *
 * Copyright (C) 2020-2030 NCC Limited. All rights reserved.
 *
 * THIS SOFTWARE IS PROVIDED BY NCC "AS IS" AND ANY EXPRESSED OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL NCC OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "nccm0670_btim.h"
#include "nccm0670_eval.h"
#include "nccm0670_rcc.h"

void btim_config(void);

int main(void)
{
    ncc_eval_led_init(LED1);
    RCC_EnablePeripheralClock(RCC_TIM6);
    btim_config();

    while (1)
    {
    }
}

void TIM6_IRQHandler(void)
{
    BTIM_ClearStatusFlag(TIM6, BTIM_FLAG_UIF);
    ncc_eval_led_toggle(LED1);
}

void btim_config(void)
{
    btim_config_t btim_cfg = {0};
    /* TIM6向上计数 */
    btim_cfg.counter_mode = BTIM_COUNTER_UP;
    /* TIM6分频系数为1000，计数频率为4M/1000=4KHz */
    btim_cfg.prescaler    = 1000 - 1;
    /* TIM6周期设为4000,定时周期为4K/4000=1Hz*/
    btim_cfg.period       = 4000 - 1;
    BTIM_Init(TIM6, &btim_cfg);
    BTIM_SetIntMode(TIM6, BTIM_INT_UIE, ENABLE);
    BTIM_Enable(TIM6);

    /*设置NVIC中断*/
    NVIC_SetPriority(TIM6_IRQn, 0);
    NVIC_EnableIRQ(TIM6_IRQn);
}