/*! @file    main.c
 *  @brief   CRC计算功能
 *  @version 2021-06-28  V1.0.0
 *
 * Copyright (C) 2020-2030 NCC Limited. All rights reserved.
 *
 * THIS SOFTWARE IS PROVIDED BY NCC "AS IS" AND ANY EXPRESSED OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL NCC OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "nccm0670_crc.h"
#include "nccm0670_eval.h"
#include "nccm0670_rcc.h"

#define DATA_LEN (5U)
static uint32_t s_data[DATA_LEN] = {0x30313233UL, 0x34353637UL, 0x3839AAABUL, 0x4142ADEFUL, 0x98756231UL};

int main(void)
{
    crc_config_t config;

    ncc_eval_led_init(LED1);

    /* 打开CRC时钟 */
    RCC_EnablePeripheralClock(RCC_CRC);
    /* 多项式选择 */
    config.polynomial             = CRC_POLYNOMIAL_32_IEEE;
    /* 输入数据不翻转 */
    config.in_data_reverse        = CRC_IN_DATA_REVERSE_NONE;
    /* 输出数据不翻转 */
    config.out_data_reverse       = CRC_OUT_DATA_REVERSE_NONE;
    /* 使用用户设置的INIT值 */
    config.default_init_value_use = CRC_DEFAULT_INIT_VALUE_DISABLE;
    /* 初始化值 */
    config.init_value             = 0x00000000UL;
    CRC_Init(&config);

    /* 将s_data数组值写入CRC模块 */
    for (int i = 0U; i < DATA_LEN; i++)
    {
        CRC_WriteData32(s_data[i]);
    }

    if (0x64011893UL == CRC_ReadData32())
    {
        /* CRC 计算正确 */
        ncc_eval_led_on(LED1);
    }

    while (1)
    {
    }
}
