/*! @file    main.c
 *  @brief   EXTI 例程
 *  @version 2021-06-28  V1.0.0
 *
 * Copyright (C) 2020-2030 NCC Limited. All rights reserved.
 *
 * THIS SOFTWARE IS PROVIDED BY NCC "AS IS" AND ANY EXPRESSED OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL NCC OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "nccm0670_eval.h"
#include "nccm0670_exti.h"
#include "nccm0670_gpio.h"
#include "nccm0670_rcc.h"

void exti_config(void);

int main(void)
{
    ncc_eval_led_init(LED1);
    /*使能GPIOC时钟*/
    RCC_EnablePeripheralClock(RCC_GPIOC);

    /*PC10输入模式，上拉*/
    GPIO_SetPinMode(GPIOC, GPIO_MODE_INPUT, GPIO_PULLUP, GPIO_PIN_9);
    exti_config();

    while (1)
    {
    }
}

void EXTI4_15_IRQHandler(void)
{ 
    /*检测上升沿中断标志*/
    if (EXTI_GetPending(EXTI_LINE_9, EXTI_TRIGGER_RISING))
    { 
        /*清除上升沿中断标志*/
        EXTI_ClearPending(EXTI_LINE_9, EXTI_TRIGGER_RISING);
        ncc_eval_led_toggle(LED1);
    }
}

void exti_config(void)
{
    exti_config_t exti_cfg = {0};

    exti_cfg.mode     = EXTI_MODE_INTERRUPT;
    exti_cfg.trigger  = EXTI_TRIGGER_RISING;
    exti_cfg.gpio_sel = EXTI_GPIOC;
    EXTI_SetConfigLine(EXTI_LINE_9, &exti_cfg);

    /*设置使能中断*/
    NVIC_SetPriority(EXTI4_15_IRQn, 5);
    NVIC_EnableIRQ(EXTI4_15_IRQn);
}