/*! @file    main.c
 *  @brief   PWM生成
 *  @version 2021-06-30  V1.0.0
 *
 * Copyright (C) 2020-2030 AIIT Limited. All rights reserved.
 *
 * THIS SOFTWARE IS PROVIDED BY AIIT "AS IS" AND ANY EXPRESSED OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL AIIT OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "nccm0670_gpio.h"
#include "nccm0670_gtim.h"
#include "nccm0670_rcc.h"

/* PWM通道选择 */
#define PWM_CHANNEL_1 (GTIM_CH_1)
#define PWM_CHANNEL_2 (GTIM_CH_2)

void rcc_config(void)
{
    RCC_EnablePeripheralClock(RCC_GPIOA);
    RCC_EnablePeripheralClock(RCC_TIM2);
}
void gpio_config(void)
{
    gpio_config_t gpio_cfg       = {0};
    gpio_cfg.mode      = GPIO_MODE_ALTERNATE;
    gpio_cfg.speed     = GPIO_SPEED_FREQ_VERY_HIGH;
    gpio_cfg.pin       = GPIO_PIN_2|GPIO_PIN_3|GPIO_PIN_4|GPIO_PIN_5;
    gpio_cfg.pull      = GPIO_NOPULL;
    gpio_cfg.alternate = GPIO_AF1_TIM2;
    GPIO_Init(GPIOA, &gpio_cfg);

}
void timer_base_init(void)
{
    gtim_base_config_t gtim_cfg  = {0};
    /* 向上计数模式 */
    gtim_cfg.counter_mode   = GTIM_COUNTER_UP;
    /* 定时器时钟 (CK_INT) 频率与数字滤波器（ ETR、 TIx）所使用的采样时钟之间的分频比 */
    gtim_cfg.clock_division = GTIM_CLOCK_DIVISION_DIV1;
    /* 计数器预分频系数设为 10 */
    gtim_cfg.prescaler      = 9;
    /* 计数器重载值设为 400，PWM输出频率为400K/400 = 1KHz */
    gtim_cfg.period         = 399;
    GTIM_Init(TIM2, &gtim_cfg);
}
void timer_compare_init(void)
{
    gtim_oc_config_t gtim_oc_cfg = {0};

    /* 通道输出使能 */
    gtim_oc_cfg.state     = GTIM_OC_OUTPUT_ENABLE;
    /* 互补通道输出使能 */
    gtim_oc_cfg.nstate    = GTIM_OC_OUTPUT_ENABLE;
    /* 通道极性为高电平有效 */
    gtim_oc_cfg.polarity  = GTIM_OC_POLARITY_HIGH;
    /* 通道极性为低电平有效 */
    gtim_oc_cfg.npolarity = GTIM_OC_POLARITY_LOW;
    GTIM_OC_Init(TIM2, PWM_CHANNEL_1, &gtim_oc_cfg);
    GTIM_OC_Init(TIM2, PWM_CHANNEL_2, &gtim_oc_cfg);
}
void timer_configuration(void)
{
    timer_base_init();
    timer_compare_init();
    
    /* 通道 1 设置PWM占空比为 25% */
    GTIM_OC_SetCompareValue(TIM2, PWM_CHANNEL_1, 100);
    /*输出模式配置,PWM1*/
    GTIM_OC_SetMode(TIM2, PWM_CHANNEL_1, GTIM_OC_MODE_PWM1);
    /*输出预装载关闭*/
    GTIM_OC_SetPreload(TIM2, PWM_CHANNEL_1, false);

    /* 通道 2 设置PWM占空比为 50% */
    GTIM_OC_SetCompareValue(TIM2, PWM_CHANNEL_2, 200);
    /*输出模式配置 PWM1模式*/
    GTIM_OC_SetMode(TIM2, PWM_CHANNEL_2, GTIM_OC_MODE_PWM1);
    /*输出预装载关闭*/
    GTIM_OC_SetPreload(TIM2, PWM_CHANNEL_2, false);

    /* 使能自动重载预装载值 */
    GTIM_SetArrPreload(TIM2, ENABLE);
    /* 使能定时器 */
    GTIM_Enable(TIM2);
}

int main(void)
{
    rcc_config();
    gpio_config();
    timer_configuration();
    while (1)
    {
    }
}
