/*! @file    main.c
 *  @brief   LPUART自动波特率例程
 *  @version 2021-07-19  V1.0.0
 *
 * Copyright (C) 2020-2030 NCC Limited. All rights reserved.
 *
 * THIS SOFTWARE IS PROVIDED BY NCC "AS IS" AND ANY EXPRESSED OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL NCC OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
 
 
#include "nccm0670_gpio.h"
#include "nccm0670_rcc.h"
#include "nccm0670_lpuart.h"
#include "nccm0670_eval.h"
#include "systick.h"

int main(void)
{
 /* 设置SYSCLK为48MHz */
    RCC_SetHsiDiv(RCC_HSI_DIV1);
    SystemCoreClockUpdate();

    systick_init();
    ncc_eval_led_init(LED1);

    ncc_eval_com_init();

    printf("\n\rLPUART auto baudrate detection example\n\r");
 
	gpio_config_t gpio_cfg = {0};
    lpuart_config_t lpuart_cfg = {0};

    RCC_EnablePeripheralClock(RCC_GPIOB);
    RCC_EnablePeripheralClock(RCC_LPUART1);

    gpio_cfg.pin       = GPIO_PIN_6 | GPIO_PIN_7;
    gpio_cfg.mode      = GPIO_MODE_ALTERNATE;
    gpio_cfg.pull      = GPIO_PULLUP;
    gpio_cfg.speed     = GPIO_SPEED_FREQ_LOW;
    gpio_cfg.alternate = GPIO_AF1_LPUART1;
    GPIO_Init(GPIOB, &gpio_cfg);

    /*帧长度，1位停止位(0.5和1相同、1.5和2相同)，奇偶校验位，传输方向 */
    lpuart_cfg.datawidth             = LPUART_DATAWIDTH_8B;   
    lpuart_cfg.stopbits              = LPUART_STOPBITS_1;      
    lpuart_cfg.parity                = LPUART_PARITY_NONE;     
    lpuart_cfg.transfer_direction    = LPUART_DIRECTION_RX; 

    LPUART_DeInit(LPUART1);
    LPUART_Init(LPUART1, &lpuart_cfg);
    LPUART_Enable(LPUART1);
	
    /* 使用自动波特率检测 */
    LPUART_SetAutoBaudRate(LPUART1, ENABLE);
    /* 请求自动波特率检测 */
    LPUART_RequestAutoBaudRate(LPUART1);

    /* 等待自动波特率检测完成 */
    while (!LPUART_GetStatusFlag(LPUART1, LPUART_FLAG_ABRF))
        ;

    /* 如果自动波特率检测发生错误 */
    if (LPUART_GetStatusFlag(LPUART1, LPUART_FLAG_ABRE))
    {
        /* 如果发生错误点亮LED1 */
        ncc_eval_led_on(LED1);
    }

    while (1)
    {
        printf("You will see this message if auto baudrate detection finished successfully\n");
        delay_ms(500);
    }
}