/*! @file    main.c
 *  @brief   TK例程
 *  @version 2021-06-28  V1.0.0
 *
 * Copyright (C) 2020-2030 NCC Limited. All rights reserved.
 *
 * THIS SOFTWARE IS PROVIDED BY NCC "AS IS" AND ANY EXPRESSED OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL NCC OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "nccm0670_adc.h"
#include "nccm0670_eval.h"
#include "nccm0670_rcc.h"
#include "nccm0670_tk.h"
#include "nccm0670_pwr.h"
#include "nccm0670_exti.h"
#include "systick.h"

void tk_test_init(uint16_t channel);
void tk_test_interrupt(uint16_t channel, tk_interrupt_t interrupt);

/* 触摸通道选择 */
#define TK_CHANNEL TK_CHANNEL_0
uint8_t flag;

int main(void)
{
    uint16_t tk_data[16];
    /* SYSTICK初始化 */
    systick_init();
    /* 调试串口初始化 */
    ncc_eval_com_init();

    tk_test_interrupt(TK_CHANNEL, TK_INT_WKUP);

    while (1)
    {
        if (flag == 1)
        {
            flag = 0;
            ncc_eval_led_toggle(LED1);
            printf("wakeup successfully\r\n");
        }
        else
        {
        }
    }
}

void tk_test_init(uint16_t channel)
{
    adc_config_t adc_cfg    = { 0 };
    RCC_EnablePeripheralClock(RCC_GPIOB);
    RCC_EnablePeripheralClock(RCC_TK);
    RCC_EnablePeripheralClock(RCC_ADC);
    
    /*选择触控通道*/
    TK_SetChannels(channel);    
    /*硬件自动触发ADC转换*/                 
    TK_SetTrigMode(TK_TRIG_HARDWARE); 
    /*选择内部高速时钟48MHz*/            
    TK_SetClockSource(TK_CLK_SRC_HSI); 
    /*充电次数 64 * (TK_CRGNUM[7:0] + 1)次*/           
    TK_SetChargeCycles(99);  
    /*间隔时间1ms*/
    TK_SetChargeInterval(TK_CHARGE_INTERVAL_1MS); 
    /*工作时钟6分频*/
    TK_SetChargeFreq(TK_CHARGE_FREQ_DIV_6); 
    /*硬件自动触发ADC转换模式时提前使能ADC时间*/      
    TK_SetHwTrigLeadTime(0xff);                   
    
    /*默认：单次转换*/
    adc_cfg.continuous_conv = ADC_CONV_SINGLE; 
    /*默认：2分频*/     
    adc_cfg.prescaler       = ADC_CLOCK_DIV2;      
    /*AVDD 5V*/ 
    adc_cfg.vref            = ADC_VREF_AVDD;       
    /*默认：上升沿触发*/ 
    adc_cfg.edge            = ADC_TRIG_EDGE_RISING; 
    /*默认：内部软件触发*/
    adc_cfg.trigger         = ADC_TRIG_SOFT;        
    ADC_Init(&adc_cfg);
}

void tk_test_interrupt(uint16_t channel, tk_interrupt_t interrupt)
{
    RCC_EnablePeripheralClock(RCC_PWR);

    /* 关系统滴答中断，防止异常唤醒 */
    SysTick->CTRL &= ~SysTick_CTRL_ENABLE_Msk; 
    NVIC_DisableIRQ(USART1_IRQn);

    RCC_EnableOSC(RCC_OSC_LSI);
    while (!(RCC->CIFR & RCC_CIFR_LSIRDYF_Msk))
        ;
    tk_test_init(channel);

    TK_Enable();
    TK_SetClockSource(TK_CLK_SRC_LSI512K);
    /*通道0，触摸通道唤醒阈值0xA00*/
    TK_SetWakeupThreshold(channel, 0xA00); 
    /*比较次数0+4，默认：按键检测后的ADC转换数据都符合设定的阈值*/
    TK_SetWakeupCriterion(0x0, TK_CRITERION_PASS_ALL); 
    TK_SetIntMode(interrupt, ENABLE);

    NVIC_EnableIRQ(TOUCH_IRQn);
    /*设置touch外部中断线*/
    exti_config_t exti_cfg;
    exti_cfg.mode    = EXTI_MODE_INTERRUPT;
    exti_cfg.trigger = EXTI_TRIGGER_RISING;
    EXTI_SetConfigLine(EXTI_LINE_19, &exti_cfg);
    /*ADC 在低功耗模式时工作时钟采用TK的时钟*/
    PWR_SetAdcPowerDown(ENABLE);
    printf("enter low power mode\r\n");

    /* 进入低功耗模式 */
    PWR_EnterStopMode(PWR_LOWPOWERREGULATOR_ON, PWR_LOWPOWER_ENTRY_WFI);
    /* 重新打开关闭的中断 */
    SysTick->CTRL |= SysTick_CTRL_ENABLE_Msk;

    NVIC_EnableIRQ(USART1_IRQn);
    ncc_eval_led_on(LED1);
}

void TOUCH_IRQHandler(void)
{
    if (TK->ISR & 0x1FFFE0)
    {
        TK->ICR = 0x1FFFE0;
        flag    = 1;
    }
}
