/*! @file    main.c
 *  @brief   USART 自动波特率例程
 *  @version 2021-06-29  V1.0.0
 *
 * Copyright (C) 2020-2030 NCC Limited. All rights reserved.
 *
 * THIS SOFTWARE IS PROVIDED BY NCC "AS IS" AND ANY EXPRESSED OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL NCC OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "nccm0670_eval.h"
#include "nccm0670_gpio.h"
#include "nccm0670_rcc.h"
#include "nccm0670_usart.h"
#include "systick.h"

int main(void)
{
    /* 设置SYSCLK为48MHz */
    RCC_SetHsiDiv(RCC_HSI_DIV1);
    SystemCoreClockUpdate();

    systick_init();
    ncc_eval_led_init(LED1);

    ncc_eval_com_init();

    printf("\n\rUSART auto baudrate detection example\n\r");
    /* 配置检测模式 */
    USART_SetAutoBaudRateMode(USART1, USART_AUTOBAUD_DETECT_ON_STARTBIT);
    /* 使用自动波特率检测 */
    USART_SetAutoBaudRate(USART1, ENABLE);
    /* 请求自动波特率检测 */
    USART_RequestAutoBaudRate(USART1);

    /* 等待自动波特率检测完成 */
    while (!USART_GetStatusFlag(USART1, USART_FLAG_ABRF))
        ;

    /* 如果自动波特率检测发生错误 */
    if (USART_GetStatusFlag(USART1, USART_FLAG_ABRE))
    {
        /* 如果发生错误点亮LED1 */
        ncc_eval_led_on(LED1);
        while (1)
        {
        }
    }

    while (1)
    {
        printf("You will see this message if auto baudrate detection finished successfully\n");
        delay_ms(500);
    }
}
