/*! @file    system_nccm0670.h
 *  @brief   nccm0670芯片设备驱动头文件
 *  @version 2021-04-23  V1.0.0
 *
 * Copyright (C) 2020-2030 NCC Limited. All rights reserved.
 *
 * THIS SOFTWARE IS PROVIDED BY NCC "AS IS" AND ANY EXPRESSED OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL NCC OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef SYSTEM_NCC0670_H
#define SYSTEM_NCC0670_H

#include <stdbool.h>

#define DISABLE false
#define ENABLE  true

#define REG_IDX_BIT(regidx, bitpos) (((uint32_t)(regidx) << 8U) | (uint32_t)(bitpos))
#define REG_IDX(idx)                (((uint32_t)(idx) >> 8U) & 0xFFU)
#define BIT_POS(idx)                ((uint32_t)(idx) & 0xFFU)
#define REG32(base, offset)         (*((volatile uint32_t*)((uint32_t)(base) + (offset))))

#if !defined(HSI_VALUE)
#define HSI_VALUE (48000000UL) /*!< 内部高速时钟频率*/
#endif                         /* HSI_VALUE */

#if !defined(LSI_VALUE)
#define LSI_VALUE (32000UL) /*!< 内部低速时钟频率*/
#endif                      /* LSI_VALUE */

#if !defined(LSE_VALUE)
#define LSE_VALUE (32768UL) /*!< 外部低速时钟频率*/
#endif                      /* LSE_VALUE */

extern uint32_t SystemCoreClock; /*!< System Clock Frequency (Core Clock) */

extern const uint8_t AHBPrescTable[16]; /*!<  AHB 分频表 */
extern const uint8_t APBPrescTable[8];  /*!< APB 分频表 */
extern const uint8_t HSIDivTable[8];    /*!< HSI 分频表 */

#ifdef __cplusplus
extern "C" {
#endif

void SystemInit(void);
void SystemCoreClockUpdate(void);

#ifdef __cplusplus
}
#endif

#endif /*SYSTEM_NCC0670_H */
