;/**************************************************************************//**
; * @file     startup_nccm0670.s
; * @brief    CMSIS Core Device Startup File for
; *           nccm0670
; * @version  V1.00
; * @date     21. April 2021
; *
; * @note
; *
; * Copyright (C) 2020-2030 NCC Limited. All rights reserved.
; *
; * THIS SOFTWARE IS PROVIDED BY NCC "AS IS" AND ANY EXPRESSED OR
; * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
; * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
; * IN NO EVENT SHALL NCC OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
; * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
; * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
; * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
; * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
; * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
; * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
; * THE POSSIBILITY OF SUCH DAMAGE.
; *
; *-------- <<< Use Configuration Wizard in Context Menu >>> ------------------
; */

; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000400

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000200

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors
                EXPORT  __Vectors_End
                EXPORT  __Vectors_Size

__Vectors       DCD     __initial_sp              ; Top of Stack
                DCD     Reset_Handler             ; Reset Handler
                DCD     NMI_Handler               ; NMI Handler
                DCD     HardFault_Handler         ; Hard Fault Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     SVC_Handler               ; SVCall Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     PendSV_Handler            ; PendSV Handler
                DCD     SysTick_Handler           ; SysTick Handler

                ; External Interrupts
 

                DCD    WWDG_IRQHandler            ;  0 WWDG Interrupt             
                DCD    PWR_IRQHandler             ;  1 PWR interrupt(combined with EXTI 16)                   
                DCD    0			        	  ;  2 Reserved         
                DCD    FLASH_IRQHandler           ;  3 FLASH Interrupt            
                DCD    RCC_IRQHandler             ;  4 RCC Interrupt              
                DCD    EXTI0_1_IRQHandler         ;  5 EXTI line 0 & 1 Interrupt  
                DCD    EXTI2_3_IRQHandler         ;  6 EXTI line 2 & 3 Interrupt  
                DCD    EXTI4_15_IRQHandler        ;  7 EXTI line 4 to 15 Interrupt
                DCD    0                          ;  8 Reserved                   
                DCD    0                          ;  9 Reserved                   
                DCD    0                          ; 10 Reserved                   
                DCD    0                          ; 11 Reserved                   
                DCD    ADC_IRQHandler             ; 12 ADC Interrupt              
                DCD    TOUCH_IRQHandler           ; 13 TOUCH Interrupt(combined with EXTI 19)           
                DCD    AWU_IRQHandler             ; 14 AWU_IRQHandler(combined with EXTI 20)            
                DCD    0                          ; 15 Reserved                   
                DCD    TIM2_IRQHandler            ; 16 TIM 2 Interrupt            
                DCD    TIM6_IRQHandler            ; 17 TIM 6 Interrupt            
                DCD    TIM7_IRQHandler            ; 18 TIM 7 Interrupt            
                DCD    0            			  ; 19 Reserved            
                DCD    TIM10_IRQHandler           ; 20 TIM 10 Interrupt           
                DCD    TIM16_IRQHandler           ; 21 TIM 16 Interrupt           
                DCD    LPUART1_IRQHandler         ; 22 LPUART1 Interrupt(combined with EXTI 17)   
                DCD    I2C1_IRQHandler            ; 23 I2C 1 Interrupt            
                DCD    0                          ; 24 Reserved          
                DCD    SPI1_IRQHandler            ; 25 SPI 1 Interrupt(combined with EXTI 18)             
                DCD    0            	          ; 26 Reserved        
                DCD    USART1_IRQHandler          ; 27 USART 1 Interrupt          
                DCD    0          				  ; 28 Reserved          
                DCD    0                          ; 29 Reserved   
                DCD    0                          ; 30 Reserved            
                DCD    0                          ; 31 Reserved  


__Vectors_End

__Vectors_Size  EQU     __Vectors_End - __Vectors

                AREA    |.text|, CODE, READONLY


; Reset Handler

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main
                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

Default_IRQHandler PROC


			EXPORT  WWDG_IRQHandler           [WEAK]  ; WWDG Interrupt               
			EXPORT  PWR_IRQHandler            [WEAK]  ; PWR Interrupt                          
            EXPORT  FLASH_IRQHandler          [WEAK]  ; FLASH Interrupt              
            EXPORT  RCC_IRQHandler            [WEAK]  ; RCC Interrupt                
            EXPORT  EXTI0_1_IRQHandler        [WEAK]  ; EXTI line 0 & 1 Interrupt    
            EXPORT  EXTI2_3_IRQHandler        [WEAK]  ; EXTI line 2 & 3 Interrupt    
            EXPORT  EXTI4_15_IRQHandler       [WEAK]  ; EXTI line 4 to 15 Interrupt  
            EXPORT  ADC_IRQHandler            [WEAK]  ; ADC Interrupt 
            EXPORT  TOUCH_IRQHandler          [WEAK]  ; TOUCH Interrupt               
            EXPORT  AWU_IRQHandler            [WEAK]  ; AWU Interrupt
            EXPORT  TIM2_IRQHandler           [WEAK]  ; TIM 2 Interrupt              
            EXPORT  TIM6_IRQHandler           [WEAK]  ; TIM 6 Interrupt              
            EXPORT  TIM7_IRQHandler           [WEAK]  ; TIM 7 Interrupt              
            EXPORT  TIM10_IRQHandler          [WEAK]  ; TIM 10 Interrupt
            EXPORT  TIM16_IRQHandler          [WEAK]  ; TIM 16 Interrupt             
            EXPORT  LPUART1_IRQHandler        [WEAK]  ; LPUART1 Interrupt             
            EXPORT  I2C1_IRQHandler           [WEAK]  ; I2C 1 Interrupt              
            EXPORT  SPI1_IRQHandler           [WEAK]  ; SPI 1 Interrupt                      
            EXPORT  USART1_IRQHandler         [WEAK]  ; USART 1 Interrupt                          
					
					
WWDG_IRQHandler               ; WWDG Interrupt             
PWR_IRQHandler                ; PWR Interrupt                      
FLASH_IRQHandler              ; FLASH Interrupt            
RCC_IRQHandler                ; RCC Interrupt              
EXTI0_1_IRQHandler            ; EXTI line 0 & 1 Interrupt  
EXTI2_3_IRQHandler            ; EXTI line 2 & 3 Interrupt  
EXTI4_15_IRQHandler           ; EXTI line 4 to 15 Interrupt
ADC_IRQHandler                ; ADC Interrupt 
TOUCH_IRQHandler              ; TOUCH Interrupt             
AWU_IRQHandler                ; AWU Interrupt
TIM2_IRQHandler               ; TIM 2 Interrupt            
TIM6_IRQHandler               ; TIM 6 Interrupt            
TIM7_IRQHandler               ; TIM 7 Interrupt            
TIM10_IRQHandler              ; TIM 10 Interrupt            
TIM16_IRQHandler              ; TIM 16 Interrupt           
LPUART1_IRQHandler            ; LPUART1 Interrupt           
I2C1_IRQHandler               ; I2C 1 Interrupt            
SPI1_IRQHandler               ; SPI 1 Interrupt                    
USART1_IRQHandler             ; USART 1 Interrupt                      

                B       .

                ENDP


                ALIGN


; User Initial Stack & Heap

                IF      :DEF:__MICROLIB

                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit

                ELSE

                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap

__user_initial_stackheap PROC
                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR
                ENDP

                ALIGN

                ENDIF


                END
