/*! @file    nccm0670_crc.h
 *  @brief   CRC固件库
 *  @version 2021-04-13  V1.0.0
 *
 * Copyright (C) 2020-2030 NCC Limited. All rights reserved.
 *
 * THIS SOFTWARE IS PROVIDED BY NCC "AS IS" AND ANY EXPRESSED OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL NCC OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef NCC0670_CRC_H
#define NCC0670_CRC_H
#include "nccm0670.h"
/*!
 * @addtogroup nccm0670_crc
 * @{
 */

/*******************************************************************************
 * Definitions
 ******************************************************************************/
/*!
 * @brief CRC使用默认的INIT值
 */
typedef enum
{
    CRC_DEFAULT_INIT_VALUE_DISABLE, /*!< 使用用户设置的INIT值 */
    CRC_DEFAULT_INIT_VALUE_ENABLE   /*!< 使用默认的INIT值：0xFFFFFFFF */
} crc_default_init_value_use_t;

/*!
 * @brief 多项式选择
 */
typedef enum
{
    CRC_POLYNOMIAL_32_IEEE, /*!< CRC-32-IEEE 802.3  */
    CRC_POLYNOMIAL_16_CCIT, /*!< CRC-16-CCIT        */
    CRC_POLYNOMIAL_16_IBM,  /*!< CRC-16-IBM         */
    CRC_POLYNOMIAL_8_8210   /*!< CRC-8: 8210        */
} crc_polynomial_t;

/*!
 * @brief 输入数据翻转
 */
typedef enum
{
    CRC_IN_DATA_REVERSE_NONE,     /*!< 32 位数据，无交换                  */
    CRC_IN_DATA_REVERSE_BYTE,     /*!< 16 位数据或半字，在字中交换每个半字  */
    CRC_IN_DATA_REVERSE_HALFWORD, /*!< 8 位数据或字节，在字中交换所有字     */
    CRC_IN_DATA_REVERSE_WORD      /*!< 1 位数据，在字中交换所有位           */
} crc_in_data_reverse_t;

/*!
 * @brief 输出数据翻转
 */
typedef enum
{
    CRC_OUT_DATA_REVERSE_NONE, /*!< 输出数据不翻转  */
    CRC_OUT_DATA_REVERSE_BIT   /*!< 输出数据按位翻转*/
} crc_out_data_reverse_t;

/*!
 * @brief CRC初始化配置结构体
 */
typedef struct
{
    crc_default_init_value_use_t default_init_value_use; /*!< 使用默认的INIT值 */
    crc_polynomial_t polynomial;                         /*!< 多项式选择 */
    crc_in_data_reverse_t in_data_reverse;               /*!< 输入数据翻转 */
    crc_out_data_reverse_t out_data_reverse;             /*!< 输出数据翻转 */
    uint32_t init_value;                                 /*!< 初始化值 */
} crc_config_t;

/*******************************************************************************
 * API
 ******************************************************************************/

#if defined(__cplusplus)
extern "C" {
#endif

void CRC_DeInit(void);
void CRC_Init(const crc_config_t *config);
void CRC_WriteData32(uint32_t data);
uint32_t CRC_ReadData32(void);
void CRC_WriteData16(uint16_t data);
uint16_t CRC_ReadData16(void);
void CRC_WriteData8(uint8_t data);
uint8_t CRC_ReadData8(void);

#if defined(__cplusplus)
}
#endif
/*! @} */
#endif /* NCC0670_CRC_H*/
/*******************************************************************************
 * EOF
 ******************************************************************************/
