/*! @file    nccm0670_dbg.h
 *  @brief   DBG固件库
 *  @version 2022-11-03  V1.0.0
 *
 * Copyright (C) 2020-2030 NCC Limited. All rights reserved.
 *
 * THIS SOFTWARE IS PROVIDED BY NCC "AS IS" AND ANY EXPRESSED OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL NCC OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef NCC0670_DBG_H
#define NCC0670_DBG_H
#include "nccm0670.h"

/*!
 * @addtogroup nccm0670_dbg
 * @{
 */
/*******************************************************************************
 * Definitions
 ******************************************************************************/
#define DBG_REGIDX_FZ1 8U
#define DBG_REGIDX_FZ2 12U
/*!
 * @brief   预分频器
 */
typedef enum
{
    DBG_IWDG_STOP  = REG_IDX_BIT(DBG_REGIDX_FZ1, DBG_APB_FZ1_DBG_IWDG_STOP_Pos),  /*!< IWDG */
    DBG_WWDG_STOP  = REG_IDX_BIT(DBG_REGIDX_FZ1, DBG_APB_FZ1_DBG_WWDG_STOP_Pos),  /*!< WWDG */
    DBG_BUZ_STOP   = REG_IDX_BIT(DBG_REGIDX_FZ1, DBG_APB_FZ1_DBG_BUZ_STOP_Pos),  /*!< BUZ */
    DBG_TIM7_STOP  = REG_IDX_BIT(DBG_REGIDX_FZ1, DBG_APB_FZ1_DBG_TIM7_STOP_Pos),  /*!< TIM7 */
    DBG_TIM6_STOP  = REG_IDX_BIT(DBG_REGIDX_FZ1, DBG_APB_FZ1_DBG_TIM6_STOP_Pos),  /*!< TIM6 */
    DBG_TIM2_STOP  = REG_IDX_BIT(DBG_REGIDX_FZ1, DBG_APB_FZ1_DBG_TIM2_STOP_Pos),  /*!< TIM2 */
    DBG_TIM16_STOP = REG_IDX_BIT(DBG_REGIDX_FZ2, DBG_APB_FZ2_DBG_TIM16_STOP_Pos), /*!< TIM16 */
    DBG_TIM10_STOP = REG_IDX_BIT(DBG_REGIDX_FZ2, DBG_APB_FZ2_DBG_TIM10_STOP_Pos), /*!< TIM10 */
} dbg_periph_t;

/*******************************************************************************
 * API
 ******************************************************************************/
#if defined(__cplusplus)
extern "C" {
#endif

void DBG_DeInit(void);
void DBG_EnableDbgStopMode(void);
void DBG_DisableDbgStopMode(void);
void DBG_FreezePeriph(dbg_periph_t periph);
void DBG_UnFreezePeriph(dbg_periph_t periph);

#if defined(__cplusplus)
}
#endif

/*! @} */

#endif /* NCC0670_DBG_H */
/*******************************************************************************
 * EOF
 ******************************************************************************/
