#include "nccm0670_eval.h"
#include "nccm0670_gpio.h"
#include "nccm0670_rcc.h"
#include "nccm0670_usart.h"
#include <stdio.h>
/* 板载LED定义 */
#define LED1_PIN             GPIO_PIN_12
#define LED1_PORT            GPIOB
#define LED1_CLK             RCC_GPIOB

#define LED2_PIN             GPIO_PIN_13
#define LED2_PORT            GPIOB
#define LED2_CLK             RCC_GPIOB
/* 板载KEY定义 */
#define KEY1_PIN             GPIO_PIN_10
#define KEY1_PORT            GPIOB
#define KEY1_CLK             RCC_GPIOB

#define KEY2_PIN             GPIO_PIN_11
#define KEY2_PORT            GPIOB
#define KEY2_CLK             RCC_GPIOB

/* 调试串口定义 */
#define EVAL_COM             USART1
#define EVAL_COM_CLK         RCC_USART1

#define EVAL_COM_TX_PORT     GPIOB
#define EVAL_COM_TX_PORT_CLK RCC_GPIOB
#define EVAL_COM_TX_PIN      GPIO_PIN_1
#define EVAL_COM_TX_AF       GPIO_AF1_USART1

#define EVAL_COM_RX_PORT     GPIOB
#define EVAL_COM_RX_PORT_CLK RCC_GPIOB
#define EVAL_COM_RX_PIN      GPIO_PIN_0
#define EVAL_COM_RX_AF       GPIO_AF1_USART1

/* LEDs */
const GPIO_Type *s_led_ports[]      = {LED1_PORT, LED2_PORT};
const uint32_t s_led_pins[]         = {LED1_PIN, LED2_PIN};
const rcc_peripheral_t s_led_clks[] = {LED1_CLK, LED2_CLK};

/* KEYs */
const GPIO_Type *s_key_ports[]      = {KEY1_PORT, KEY2_PORT};
const uint32_t s_key_pins[]         = {KEY1_PIN, KEY2_PIN};
const rcc_peripheral_t s_key_clks[] = {KEY1_CLK, KEY2_CLK};

/* LED初始化 */
void ncc_eval_led_init(ncc_eval_led_t led)
{
    gpio_config_t cfg;

    cfg.pin         = s_led_pins[led];
    cfg.mode        = GPIO_MODE_OUTPUT;
    cfg.pull        = GPIO_NOPULL;
    cfg.speed       = GPIO_SPEED_FREQ_LOW;
    cfg.output_type = GPIO_OUTPUT_PUSHPULL;

    RCC_EnablePeripheralClock(s_led_clks[led]);
    GPIO_Init((GPIO_Type *)s_led_ports[led], &cfg);
}
/* 打开LED */
void ncc_eval_led_on(ncc_eval_led_t led)
{
    GPIO_WritePins((GPIO_Type *)s_led_ports[led], s_led_pins[led], true);
}
/* 关闭LED */
void ncc_eval_led_off(ncc_eval_led_t led)
{
    GPIO_WritePins((GPIO_Type *)s_led_ports[led], s_led_pins[led], false);
}
/* 翻转LED */
void ncc_eval_led_toggle(ncc_eval_led_t led)
{
    GPIO_TogglePin((GPIO_Type *)s_led_ports[led], s_led_pins[led]);
}

/* KEY初始化 */
void ncc_eval_key_init(ncc_eval_key_t key)
{
    gpio_config_t cfg;

    cfg.pin   = s_key_pins[key];
    cfg.mode  = GPIO_MODE_INPUT;
    cfg.pull  = GPIO_PULLUP;
    cfg.speed = GPIO_SPEED_FREQ_LOW;

    RCC_EnablePeripheralClock(s_key_clks[key]);
    GPIO_Init((GPIO_Type *)s_key_ports[key], &cfg);
}
/* 获取KEY状态 */
uint8_t ncc_eval_key_state_get(ncc_eval_key_t key)
{
    return GPIO_ReadPins((GPIO_Type *)s_key_ports[key], s_key_pins[key]) ? 1 : 0;
}

/* 调试串口初始化 */
void ncc_eval_com_init(void)
{
    gpio_config_t gpio_cfg    = {0};
    usart_base_cfg_t uart_cfg = {0};

    RCC_EnablePeripheralClock(EVAL_COM_CLK);
    RCC_EnablePeripheralClock(EVAL_COM_TX_PORT_CLK);
    RCC_EnablePeripheralClock(EVAL_COM_RX_PORT_CLK);

    gpio_cfg.pin       = EVAL_COM_TX_PIN;
    gpio_cfg.mode      = GPIO_MODE_ALTERNATE;
    gpio_cfg.pull      = GPIO_NOPULL;
    gpio_cfg.speed     = GPIO_SPEED_FREQ_LOW;
    gpio_cfg.alternate = EVAL_COM_TX_AF;
    GPIO_Init(EVAL_COM_TX_PORT, &gpio_cfg);

    gpio_cfg.pin       = EVAL_COM_RX_PIN;
    gpio_cfg.alternate = EVAL_COM_RX_AF;
    GPIO_Init(EVAL_COM_RX_PORT, &gpio_cfg);

    uart_cfg.baudrate           = 115200UL;
    uart_cfg.datawidth          = USART_DATAWIDTH_8B;
    uart_cfg.parity             = USART_PARITY_NONE;
    uart_cfg.stopbits           = USART_STOPBITS_1;
    uart_cfg.transfer_direction = USART_DIRECTION_TX_RX;
    USART_DeInit(EVAL_COM);
    USART_Init(EVAL_COM, &uart_cfg);
    USART_Enable(EVAL_COM);
}

/* 重定向printf函数 */
int fputc(int ch, FILE *f)
{
    USART_TransmitData(EVAL_COM, (uint32_t)ch);
    while (!USART_GetStatusFlag(EVAL_COM, USART_FLAG_TC))
        ;
    USART_ClearStatusFlag(EVAL_COM, USART_FLAG_TC);
    return ch;
}
